CustomStepRegistry class
Registry for custom step implementations.
Allows users to register custom step handlers that will be checked before falling back to the built-in step implementations.
Constructors
- CustomStepRegistry()
-
factory
Properties
-
exactHandlers
→ Map<
String, CustomStepHandler> -
Get all registered exact handlers (for debugging/inspection).
no setter
- handlerCount → int
-
Get the number of registered custom step handlers.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
patternHandlers
→ Map<
RegExp, CustomStepHandler> -
Get all registered pattern handlers (for debugging/inspection).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clear all registered custom step handlers.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerExact(
String stepText, CustomStepHandler handler) → void - Register a custom step handler with exact text matching.
-
registerPattern(
RegExp pattern, CustomStepHandler handler) → void - Register a custom step handler with a regex pattern.
-
registerTemplate(
String template, CustomStepHandler handler) → void - Register a custom step handler with a simple text pattern using placeholders.
-
toString(
) → String -
A string representation of this object.
inherited
-
tryExecuteCustomStep(
String step, WidgetTester tester) → Future< bool> - Try to execute a step using registered custom handlers.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited